@@ -247,12 +247,12 @@ class gjotsfile:
 		feedback = " "
 		confirm = password
 		dirname, basename = os.path.split(filename)
-		prompt = "Enter password for " + basename
+		prompt = _("Enter password for ") + basename
 		while 1:
-			general = general_dialog(self.gui, "gjots: Enter Password", prompt, OK|CANCEL,
+			general = general_dialog(self.gui, _("gjots: Enter Password"), prompt, OK|CANCEL,
 									 num_fields, secretp, feedback,
-									 "Password: ", password,
-									 "Confirm: ",  confirm)
+									 _("Password: "), password,
+									 _("Confirm: "),  confirm)
 			if not general.get_value() == OK:
 				raise PasswordError
 			
@@ -260,14 +260,14 @@ class gjotsfile:
 			confirm = general.get_field2()
 			if mode == "r" or password == confirm:
 				break
-			feedback = "Password was not confirmed"
+			feedback = _("Password was not confirmed")
 		return password
 	
 	def ccrypt_open(self, filename, mode = "r"):
 		if self.gui.trace:
 			print inspect.getframeinfo(inspect.currentframe())[2], vars()
 		if os.system("type ccdecrypt >/dev/null 2>&1") != 0:
-			self.gui.err_msg("Could not find the ccrypt program - please install it and try again")
+			self.gui.err_msg(_("Could not find the ccrypt program - please install it and try again"))
 			raise PasswordError
 		
 		# get a password:
@@ -296,7 +296,7 @@ class gjotsfile:
 		if self.gui.trace:
 			print inspect.getframeinfo(inspect.currentframe())[2], vars()
 		if os.system("type gpg >/dev/null 2>&1") != 0:
-			self.gui.err_msg("Could not find the gpg program - please install it and try again")
+			self.gui.err_msg(_("Could not find the gpg program - please install it and try again"))
 			raise PasswordError
 		
 		# get a password:
@@ -321,7 +321,7 @@ class gjotsfile:
 		if self.gui.trace:
 			print inspect.getframeinfo(inspect.currentframe())[2], vars()
 		if os.system("type openssl >/dev/null 2>&1") != 0:
-			self.gui.err_msg("Could not find the openssl program - please install it and try again")
+			self.gui.err_msg(_("Could not find the openssl program - please install it and try again"))
 			raise PasswordError
 		
 		# get a password:
@@ -384,13 +384,13 @@ class gjotsfile:
 		try:
 			f = self._general_open(filename, "r")
 		except IOError:
-			self.gui.msg('Can\'t open "' + basename + '"')
+			self.gui.msg(_('Can\'t open "') + basename + '"')
 			return ""
 		except PasswordselectionError:
-			self.gui.msg("Bad password")
+			self.gui.msg(_("Bad password"))
 			return ""
 		except LockingError:
-			self.gui.err_msg("File cannot be locked")
+			self.gui.err_msg(_("File cannot be locked"))
 			return ""
 
 		if import_after:
@@ -426,22 +426,22 @@ class gjotsfile:
 			f = self._general_open(filename, "w")
 		except IOError:
 			dirname, basename = os.path.split(filename)
-			self.gui.msg("Not saved.")
-			self.gui.err_msg("Can't write to " + basename)
+			self.gui.msg(_("Not saved."))
+			self.gui.err_msg(_("Can't write to ") + basename)
 			return ""
 		except LockingError:
-			self.gui.err_msg("Can't lock file")
+			self.gui.err_msg(_("Can't lock file"))
 			return ""
 
 		if selection:
 			first_selected = self.gui.get_first_selected_iter()
 			if not first_selected:
-				self.gui.msg("Nothing selected")
+				self.gui.msg(_("Nothing selected"))
 				return ""
 
 			last_selected = self.gui.get_last_selected_iter()
 			if not last_selected:
-				self.gui.msg("Nothing selected")
+				self.gui.msg(_("Nothing selected"))
 				return ""
 
 			this = first_selected
@@ -504,7 +504,7 @@ class gjotsfile:
 		}
 
 		self.name = "fileselection"
-		self.xml = gtk.glade.XML(self.gui.gui_filename, self.name)
+		self.xml = gtk.glade.XML(self.gui.gui_filename, self.name, domain="gjots2")
 		self.xml.signal_autoconnect(callbacks)
 		
 		self.xml.get_widget(self.name).set_title(title)
@@ -541,7 +541,7 @@ class gjotsfile:
 			readonly = 1
 			
 		if not os.access(self.prompt_filename, os.R_OK):
-			self.gui.err_msg("%s is not readable" % basename)
+			self.gui.err_msg(_("%s is not readable") % basename)
 			return ""
 		
 		# lock the file
@@ -551,11 +551,11 @@ class gjotsfile:
 				# it's locked, all in order...
 				break
 			if reason == 1:
-				msg = "%s: no permission" % basename
+				msg = _("%s: no permission") % basename
 			else:
-				msg = "%s: locked by process number %d" % (basename, pid)
+				msg = _("%s: locked by process number %d") % (basename, pid)
 			general = general_dialog(self.gui,
-									 title = "gjots: can't lock file.",
+									 title = _("gjots: can't lock file."),
 									 prompt = msg,
 									 buttons = TRYAGAIN | CANCEL | READONLY,
 									 secretp = 0,
@@ -603,7 +603,7 @@ class gjotsfile:
 
 		if self.gui.readonly or not self.filename:
 			if not prompt or len(prompt) == 0:
-				prompt = "Save as ..."
+				prompt = _("Save as ...")
 
 		retval = ""
 		while 1: # use while simply so that we can use break:
@@ -615,7 +615,7 @@ class gjotsfile:
 					# we may need to use "fully expanded name" here:
 					if self.filename == self.prompt_filename:
 						if exporting:
-							self.gui.err_msg("That file is already open!")
+							self.gui.err_msg(_("That file is already open!"))
 							return ""
 						retval = self._do_store(self.filename, exporting)
 						break
@@ -623,10 +623,10 @@ class gjotsfile:
 					reason, pid = self.lock_file(self.prompt_filename)
 
 					if reason == 2:
-						self.gui.err_msg("%s is locked by pid %d" % (basename, pid))
+						self.gui.err_msg(_("%s is locked by pid %d") % (basename, pid))
 						return ""
 					if reason == 1:
-						self.gui.err_msg("Can't make a lockfile in " + dirname)
+						self.gui.err_msg(_("Can't make a lockfile in ") + dirname)
 						return ""
 
 					# We know that the directory is writable, so we can
@@ -638,10 +638,10 @@ class gjotsfile:
 
 						if not os.access(self.prompt_filename, os.W_OK):
 							self.unlock_file(self.prompt_filename)
-							self.gui.err_msg("%s is not writable" % basename)
+							self.gui.err_msg(_("%s is not writable") % basename)
 							return ""
-						general = general_dialog(self.gui, "gjots: %s already exists." % basename,
-												 "overwrite %s?" % basename, YES|CANCEL,
+						general = general_dialog(self.gui, _("gjots: %s already exists.") % basename,
+												 _("overwrite %s?") % basename, YES|CANCEL,
 												 0, 0, "",
 												 "", "",
 												 "",  "")
