@@ -151,7 +151,7 @@ class find_dialog:
 				try:
 					self.prog = re.compile(find_text, options)
 				except:
-					self.gui.err_msg("Bad regular expression")
+					self.gui.err_msg(_("Bad regular expression"))
 					use_textBuffer = 0
 					continue
 				
@@ -195,9 +195,9 @@ class find_dialog:
 		self.feedback("")
 
 		if not self._find_next():
-			self.feedback("Not found")
+			self.feedback(_("Not found"))
 		else:
-			self.feedback("Found")
+			self.feedback(_("Found"))
 			
 	def on_findCloseButton_clicked(self, widget):
 		if self.gui.trace:
@@ -248,10 +248,10 @@ class find_dialog:
 		self.feedback("")
 
 		if not self._replace_next():
-			self.feedback("Not found")
+			self.feedback(_("Not found"))
 			return
 
-		self.feedback("Replace?")
+		self.feedback(_("Replace?"))
 		return
 		
 	def on_replaceAllButton_clicked(self, widget):
@@ -264,7 +264,7 @@ class find_dialog:
 		while i:
 			i = self._replace_next()
 			total = total + i
-		self.feedback("%d substitutions" % total)
+		self.feedback(_("%d substitutions") % total)
 		return
 	
 	def on_findCancelButton_clicked(self, widget):
@@ -328,7 +328,7 @@ class find_dialog:
 			"on_findClearButton_clicked":				self.on_findClearButton_clicked 
 		}
 		self.name = "findDialog"
-		self.xml = gtk.glade.XML(self.gui.gui_filename, self.name)
+		self.xml = gtk.glade.XML(self.gui.gui_filename, self.name, domain="gjots2")
 		self.xml.signal_autoconnect(callbacks)
 
 		w = self.xml.get_widget("caseCheckbutton")
