@@ -8,6 +8,7 @@ import pango
 import time # for strftime
 import pipes
 import inspect
+import gettext
 
 from file import *
 from prefs import *
@@ -19,7 +20,6 @@ from printDialog import *
 from sortDialog import *
 from version import *
 
-
 """
 
 Notes:
@@ -94,7 +94,7 @@ class gjots_gui:
 		else:
 			bin = text_formatter
 		if os.system("type %s >/dev/null 2>&1" % bin):
-			self.err_msg("External formatter \"%s\" is not installed - can't format" % bin)
+			self.err_msg(_("External formatter \"%s\" is not installed - can't format") % bin)
 			return
 		
 		start_iter = self._start_of_para()
@@ -324,7 +324,7 @@ class gjots_gui:
 
 		# There is no get_bool_with_default() so we have to test for first invocation:
 		if not self.client.get_bool(self.initialised_path):
-			print "not initialised"
+			print _("not initialised")
 			self.client.set_bool(self.top_toolbar_path, 1)
 			self.client.set_bool(self.side_toolbar_path, 1)
 			self.client.set_bool(self.show_icon_text_path, 0)
@@ -541,25 +541,25 @@ class gjots_gui:
 		self.msg("")
 		first_selected = self.get_first_selected_iter()
 		if not first_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		parent = self.treestore.iter_parent(first_selected)
 		if not parent:
-			self.msg("No parent!")
+			self.msg(_("No parent!"))
 			return
 		this = self.treestore.iter_children(parent) # returns first sibling of first_selected
 		if not this:
-			self.msg("No child!")
+			self.msg(_("No child!"))
 			return
 		if self.same_iter(this, first_selected):
-			self.msg("Can't go any further")
+			self.msg(_("Can't go any further"))
 			return
 
 		# scan the siblings until we get to the first_selected:
 		while (this):
 			next = self.treestore.iter_next(this)
 			if not next:
-				self.msg("Internal error!")
+				self.msg(_("Internal error!"))
 				return
 			if self.same_iter(next, first_selected):
 				pivot = this
@@ -582,27 +582,27 @@ class gjots_gui:
 		self.msg("")
 		first_selected = self.get_first_selected_iter()
 		if not first_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		last_selected = self.get_last_selected_iter()
 		if not last_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 
 		parent = self.treestore.iter_parent(last_selected)
 		if not parent:
-			self.msg("No parent!")
+			self.msg(_("No parent!"))
 			return
 
 		pivot = self.treestore.iter_next(last_selected)
 		if not pivot:
-			self.msg("Can't go any further")
+			self.msg(_("Can't go any further"))
 			return
 
 		# now scan siblings looking for selected items and moving after pivot
 		this = self.treestore.iter_children(parent) # returns first sibling of last_selected
 		if not this:
-			self.msg("No child!")
+			self.msg(_("No child!"))
 			return
 
 		while this:
@@ -625,23 +625,26 @@ class gjots_gui:
 		if self.trace:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		self.msg("")
+		self.sync_text_buffer()
 		first_selected = self.get_first_selected_iter()
 		if not first_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		last_selected = self.get_last_selected_iter()
 		if not last_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		parent = self.treestore.iter_parent(last_selected)
 		if not parent:
-			self.msg("No parent!")
+			self.msg(_("No parent!"))
 			return
 		grandparent = self.treestore.iter_parent(parent)
 		if not grandparent:
-			self.msg("Can't go further!")
+			self.msg(_("Can't go further!"))
 			return
 
+		# temporarily disconnect selection updating as structure is unstable (bug 1250753):
+		self.treeView.get_selection().disconnect(self.on_tree_selection_changed_handler)
 		f = tempfile.TemporaryFile()
 		this = first_selected
 		while this:
@@ -665,6 +668,7 @@ class gjots_gui:
 			self.treeView.get_selection().select_iter(this)
 			this = next
 
+		self.on_tree_selection_changed_handler = self.treeView.get_selection().connect("changed", self.on_tree_selection_changed)
 		self.dirtyflag = "* "
 
 	def _do_move_right(self):
@@ -681,19 +685,20 @@ class gjots_gui:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		
 		self.msg("")
+		self.sync_text_buffer()
 		first_selected = self.get_first_selected_iter()
 		if not first_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		
 		last_selected = self.get_last_selected_iter()
 		if not last_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		
 		parent = self.treestore.iter_parent(last_selected)
 		if not parent:
-			self.msg("No parent!")
+			self.msg(_("No parent!"))
 			return
 
 		newParent = self.treestore.iter_children(parent) # returns first sibling of selected items
@@ -711,12 +716,14 @@ class gjots_gui:
 				newParent = next
 
 		if not newParent:
-			self.msg("Internal error!")
+			self.msg(_("Internal error!"))
 			return
 		
 		# write out items to temporary file: 
 		f = tempfile.TemporaryFile()
 		this = first_selected
+		# temporarily disconnect selection updating as structure is unstable (bug 1250753):
+		self.treeView.get_selection().disconnect(self.on_tree_selection_changed_handler)
 		while this:
 			next = self.treestore.iter_next(this)
 			if self.same_iter(this, last_selected):
@@ -754,6 +761,7 @@ class gjots_gui:
 			self.treeView.get_selection().select_iter(this)
 			this = next
 			
+		self.on_tree_selection_changed_handler = self.treeView.get_selection().connect("changed", self.on_tree_selection_changed)
 		self.dirtyflag = "* "
 	
 	def _new_tree_cut_buffer(self):
@@ -789,7 +797,7 @@ class gjots_gui:
 		
 		parent = self.treestore.iter_parent(this)
 		if not parent:
-			self.msg("No parent!")
+			self.msg(_("No parent!"))
 			return
 		
 		iter = self.treestore.iter_children(parent)
@@ -828,7 +836,7 @@ class gjots_gui:
 		if text and len(text):
 			if self.clipboard:
 				self.textBuffer.cut_clipboard(self.clipboard, self.textView.get_editable())
-				self.msg("Text cut")
+				self.msg(_("Text cut"))
 		return
 		
 	def _do_text_copy(self):
@@ -839,7 +847,7 @@ class gjots_gui:
 		if text and len(text):
 			if self.clipboard:
 				self.textBuffer.copy_clipboard(self.clipboard)
-				self.msg("Text copied")
+				self.msg(_("Text copied"))
 		return
 
 	def _do_text_paste(self):
@@ -851,7 +859,7 @@ class gjots_gui:
 			cursor_mark = self.textBuffer.get_insert()
 			insert_iter = self.textBuffer.get_iter_at_mark(cursor_mark)
 			self.textBuffer.paste_clipboard(self.clipboard, insert_iter, self.textView.get_editable())
-			self.msg("Text pasted")
+			self.msg(_("Text pasted"))
 		return
 
 	def _do_text_select_all(self):
@@ -860,13 +868,13 @@ class gjots_gui:
 		self.msg("")
 		self.textBuffer.select_range(self.textBuffer.get_start_iter(),
 			self.textBuffer.get_end_iter())
-		self.msg("All text selected")
+		self.msg(_("All text selected"))
 		return
 
 	def _do_tree_select_all(self):
 		self.msg("")
 		self.treeView.get_selection().select_all()
-		self.msg("All tree items selected")
+		self.msg(_("All tree items selected"))
 
 	def _do_split_item(self):
 		if self.trace:
@@ -874,7 +882,7 @@ class gjots_gui:
 		self.msg("")
 		body, start_iter, end_iter = self.get_selected_text()
 		if not body:
-			self.msg("Nothing selected!")
+			self.msg(_("Nothing selected!"))
 			return
 		self.textBuffer.delete(start_iter, end_iter)
 		self.sync_text_buffer()
@@ -894,28 +902,30 @@ class gjots_gui:
 		self.msg("")
 		first_selected = self.get_first_selected_iter()
 		if not first_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 
 		if self.same_iter(first_selected, self.get_root()):
-			self.msg("Can't merge the root item")
+			self.msg(_("Can't merge the root item"))
 			return
 		
 		last_selected = self.get_last_selected_iter()
 		if not last_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 
 		if self.same_iter(first_selected, last_selected):
-			self.msg("Nothing to merge")
+			self.msg(_("Nothing to merge"))
 			return
 
 		# First, make sure nothing has a child:
 		this = first_selected
-		while not self.same_iter(this, last_selected):
+		while this:
 			if self.treestore.iter_children(this):
-				msg("Can't merge items that have children")
+				self.msg(_("Can't merge items that have children"))
 				return
+			if self.same_iter(this, last_selected):
+				break
 			this = self.treestore.iter_next(this)
 
 		# Copy the text into the first one selected:
@@ -942,7 +952,7 @@ class gjots_gui:
 			this = next
 		
 		self.dirtyflag = "* "
-		self.msg("%d items merged" % count)
+		self.msg(_("%d items merged") % count)
 		return
 
 	def _show_all(self, item):
@@ -983,16 +993,16 @@ class gjots_gui:
 		self.msg("")
 		first_selected = self.get_first_selected_iter()
 		if not first_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 
 		if self.same_iter(first_selected, self.get_root()):
-			self.msg("Can't delete the root item")
+			self.msg(_("Can't delete the root item"))
 			return
 		
 		last_selected = self.get_last_selected_iter()
 		if not last_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 
 		new_selection = self.treestore.iter_next(last_selected)
@@ -1017,7 +1027,7 @@ class gjots_gui:
 		if new_selection:
 			self.treeView.get_selection().select_iter(new_selection)
 		self.dirtyflag = "* "
-		self.msg("%d tree items cut" % count)
+		self.msg(_("%d tree items cut") % count)
 
 	def _do_tree_copy(self):
 		if self.trace:
@@ -1025,12 +1035,12 @@ class gjots_gui:
 		self.msg("")
 		first_selected = self.get_first_selected_iter()
 		if not first_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		
 		last_selected = self.get_last_selected_iter()
 		if not last_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		
 		self._new_tree_cut_buffer()
@@ -1044,30 +1054,30 @@ class gjots_gui:
 			self.gjotsfile.writeItem(self.tree_cutbuffer, this, 0)
 			this = next
 		#self._enable_tree_paste()
-		self.msg("%d tree items copied" % count)
+		self.msg(_("%d tree items copied") % count)
 				
 	def _do_tree_paste(self):
 		if self.trace:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		self.msg("")
 		if not self.tree_cutbuffer:
-			self.msg("Nothing to paste")
+			self.msg(_("Nothing to paste"))
 			return
 		
 		last_selected = self.get_last_selected_iter()
 		if not last_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		
 		parent = self.treestore.iter_parent(last_selected)
 		if not parent:
-			self.msg("No parent!")
+			self.msg(_("No parent!"))
 			return
 
 		self.tree_cutbuffer.seek(0, 0)
 		last_selected = self.gjotsfile.readItem(self.tree_cutbuffer, last_selected, parent)
 		self.dirtyflag = "* "
-		self.msg("Tree items pasted")
+		self.msg(_("Tree items pasted"))
 
 	def _do_external_edit(self):
 		if self.trace:
@@ -1085,7 +1095,7 @@ class gjots_gui:
 			f.write(body)
 			f.close()
 		except IOError:
-			self.msg("Can't write " + scratch)
+			self.msg(_("Can't write ") + scratch)
 			os.unlink(scratch)
 			return
 
@@ -1095,7 +1105,7 @@ class gjots_gui:
 		else:
 			ext_ed_string = (external_editor + " %s" % scratch)
 		if os.system(ext_ed_string) != 0:
-			self.err_msg("Can't run '%s'" % ext_ed_string)
+			self.err_msg(_("Can't run '%s'") % ext_ed_string)
 			os.unlink(scratch)
 			return
 		try:
@@ -1104,7 +1114,7 @@ class gjots_gui:
 			f.close()
 			os.unlink(scratch)
 		except:
-			self.msg("Can't read " + scratch)
+			self.msg(_("Can't read ") + scratch)
 			f.close()
 			os.unlink(scratch)
 			return
@@ -1112,9 +1122,9 @@ class gjots_gui:
 			self.textBuffer.set_text(newbody, len(newbody))
 			self.current_dirty = 1
 			self.dirtyflag = "* "
-			self.msg("text changed by external editor")
+			self.msg(_("text changed by external editor"))
 		else:
-			self.msg("text not changed by external editor")
+			self.msg(_("text not changed by external editor"))
 			
 	def msg(self, message):
 		if self.trace:
@@ -1132,7 +1142,7 @@ class gjots_gui:
 	def err_msg(self, message):
 		if self.trace:
 			print inspect.getframeinfo(inspect.currentframe())[2], vars()
-		general = general_dialog(self, self.progName + ": Error", message, OK)
+		general = general_dialog(self, self.progName + _(": Error"), message, OK)
 
 	def set_readonly(self, readonly, quietly):
 		if self.trace:
@@ -1145,7 +1155,7 @@ class gjots_gui:
 			if failed:
 				readonly = 1
 				if not quietly:
-					self.err_msg("Can't lock file %s: already locked by process %d" % (self.gjotsfile.filename, pid))
+					self.err_msg(_("Can't lock file %s: already locked by process %d") % (self.gjotsfile.filename, pid))
 
 		self.readonly = readonly
 
@@ -1251,8 +1261,8 @@ class gjots_gui:
 		if self.trace:
 			print "_save_if_dirty"
 		if self.dirtyflag:
-			general = general_dialog(self, self.progName + ": Save?",
-									 "Save current work?", YES|NO|CANCEL,
+			general = general_dialog(self, self.progName + _(": Save?"),
+									 _("Save current work?"), YES|NO|CANCEL,
 									 0, 0, "",
 									 "", "",
 									 "",  "")
@@ -1273,7 +1283,7 @@ class gjots_gui:
 
 		self._create_empty_tree()
 		self.dirtyflag = ""
-		self.msg("New file")
+		self.msg(_("New file"))
 		
 	def on_open_trigger(self, widget):
 		if self.trace:
@@ -1289,7 +1299,7 @@ class gjots_gui:
 			return
 		self.gjotsfile.close() # does python have a destructor mechanism?
 		self.gjotsfile = gjotsfile(self)
-		if self.gjotsfile.read_file("Open file ...", None, self.readonly, import_after=None):
+		if self.gjotsfile.read_file(_("Open file ..."), None, self.readonly, import_after=None):
 			self.dirtyflag = ""
 
 	def _do_save(self):
@@ -1298,13 +1308,13 @@ class gjots_gui:
 		self.msg("")
 		self.sync_text_buffer()
 		if not self.dirtyflag:
-			self.msg("No changes to save")
+			self.msg(_("No changes to save"))
 			return
 		if self.gjotsfile.write_file(prompt="", exporting=0):
 			self.dirtyflag = ""
-			self.msg("Saved.")
+			self.msg(_("Saved."))
 		else:
-			self.msg("Not saved.")
+			self.msg(_("Not saved."))
 		return
 
 	def on_save_trigger(self, widget):
@@ -1318,13 +1328,13 @@ class gjots_gui:
 		self.msg("")
 		self.sync_text_buffer()
 		if not self.gjotsfile:
-			self.msg("Nothing to save")
+			self.msg(_("Nothing to save"))
 			return
-		if self.gjotsfile.write_file("Save as ...", exporting=0):
+		if self.gjotsfile.write_file(_("Save as ..."), exporting=0):
 			self.dirtyflag = ""
-			self.msg("Saved.")
+			self.msg(_("Saved."))
 		else:
-			self.msg("Not saved.")
+			self.msg(_("Not saved."))
 		return
 
 	def on_import_trigger(self, widget):
@@ -1334,10 +1344,10 @@ class gjots_gui:
 		self.msg("")
 		import_after = self.get_last_selected_iter()
 		if import_after:
-			if self.gjotsfile.read_file("Import from ...", None, 1, import_after):
+			if self.gjotsfile.read_file(_("Import from ..."), None, 1, import_after):
 				self.dirtyflag = "* "
 		else:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 		return
 
 	def on_export_trigger(self, widget):
@@ -1345,7 +1355,7 @@ class gjots_gui:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		self.sync_text_buffer()
 		self.msg("")
-		self.gjotsfile.write_file("Export to ...", exporting=1)
+		self.gjotsfile.write_file(_("Export to ..."), exporting=1)
 		return
 
 	def on_print_trigger(self, widget):
@@ -1599,24 +1609,51 @@ class gjots_gui:
 
 		# Determine the path for the gjots2.gjots documentation file to
 		# open.
+		gjots_file = ""
 		if os.access("./gjots2.gjots", os.R_OK):
-			gjots_cmd += " ./gjots2.gjots"
-			sys.stderr.write("%s: Warning: opening gjots2 manual from %s\n" % ("gjots2", gjots_cmd))
+			gjots_file = "./gjots2.gjots"
+			sys.stderr.write(_("%s: Warning: opening gjots2 manual from %s\n") % ("gjots2", gjots_file))
 		elif os.access("./doc/gjots2.gjots", os.R_OK):
-			gjots_cmd += " ./doc/gjots2.gjots"
-			sys.stderr.write("%s: Warning: opening gjots2 manual from %s\n" % ("gjots2", gjots_cmd))
-		else:  # run from the system share directory
-			gjots_cmd += self.prefix + "/share/doc/gjots2-" + gjots_version + "/gjots2.gjots"
+			gjots_file = "./doc/gjots2.gjots"
+			sys.stderr.write(_("%s: Warning: opening gjots2 manual from %s\n") % ("gjots2", gjots_file))
+		else:  # run from the system share directory - try to find a locale version:
+			gjots_file_base = self.prefix + "/share/doc/gjots2-" + gjots_version + "/gjots2"
+			for env in "LANGUAGE", "LC_ALL", "LC_MESSAGES", "LANG":
+				locale = os.environ[env]
+				locale_lang = locale[0:2]
+				try:
+					gjots_file = gjots_file_base + "." + locale + ".gjots"
+					if os.access(gjots_file, os.R_OK):
+						break
+					else:
+						gjots_file=""
+				except KeyError:
+					gjots_file=""
+					pass
+				try:
+					gjots_file = gjots_file_base + "." + locale_lang + ".gjots"
+					if os.access(gjots_file, os.R_OK):
+						break
+					else:
+						gjots_file=""
+				except KeyError:
+					gjots_file=""
+					pass
+				
+			if gjots_file == "":
+				gjots_file = gjots_file_base + ".gjots"
 
 		# Execute gjots to open its documentation.
-		os.system(gjots_cmd + " &")
+		if os.access(gjots_file, os.R_OK):
+			gjots_cmd += gjots_file + "&"
+			os.system(gjots_cmd)
 		return
 
 	def on_about_trigger(self, widget):
 		if self.trace:
 			print inspect.getframeinfo(inspect.currentframe())[2]
 		self.msg("")
-		about = gtk.glade.XML(self.gui_filename, "about")
+		about = gtk.glade.XML(self.gui_filename, "about", domain="gjots2")
 		w = about.get_widget("about")
 		w.set_property('name', 'Gjots2')
 		w.set_property('version', gjots_version)
@@ -1768,13 +1805,13 @@ class gjots_gui:
 			try:
 				selection_list = selection.get_selected_rows()
 			except AttributeError:
-				self.err_msg("pygtk-2.2 is required for this application!")
+				self.err_msg(_("pygtk-2.2 is required for this application!"))
 				gtk.main_quit()
 				return
 			# Bug fix to check for a null selection list to prevent GTK from
 			# segfaulting.
 			if selection_list == None or selection_list[1] == None:
-				print "gjots2: warning: selection list is NULL. Skipping tree selection changed \nevent."
+				print _("gjots2: warning: selection list is NULL. Skipping tree selection changed \nevent.")
 				return
 			path_list = selection_list[1]
 			parent = self.treestore.iter_parent(first_selected)
@@ -1825,15 +1862,15 @@ class gjots_gui:
 
 		first_selected = self.get_first_selected_iter()
 		if not first_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		parent = self.treestore.iter_parent(first_selected)
 		if not parent:
-			self.msg("No parent!")
+			self.msg(_("No parent!"))
 			return
 		iter = self.treestore.iter_children(parent)
 		if iter == None or self.same_iter(iter, first_selected):
-			self.msg("Can't go further")
+			self.msg(_("Can't go further"))
 			return None
 
 		self._warp(iter)
@@ -1844,7 +1881,7 @@ class gjots_gui:
 
 		last_selected = self.get_last_selected_iter()
 		if not last_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 
 		iter = last_selected
@@ -1862,7 +1899,7 @@ class gjots_gui:
 
 		iter = self.treestore.get_iter_first()
 		if not iter:
-			self.msg("Tree is empty!")
+			self.msg(_("Tree is empty!"))
 			return
 		
 		self._warp(iter)
@@ -1873,7 +1910,7 @@ class gjots_gui:
 
 		last_selected = self.get_last_selected_iter()
 		if not last_selected:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 
 		iter = last_selected
@@ -1896,7 +1933,7 @@ class gjots_gui:
 
 		iter = self.get_first_selected_iter()
 		if not iter:
-			self.msg("Nothing selected")
+			self.msg(_("Nothing selected"))
 			return
 		path = self.treestore.get_path(iter)
 		if self.treeView.row_expanded(path):
@@ -2003,7 +2040,7 @@ class gjots_gui:
 					width = long(m.group(1))
 					height = long(m.group(2))
 				else:
-					sys.stderr.write("%s: bad geometry specification: %s\n" % (self.progName, self.geometry))
+					sys.stderr.write(_("%s: bad geometry specification: %s\n") % (self.progName, self.geometry))
 					sys.exit(1)
 				self.geometry = ""
 			if height == 0 and width == 0 and self.client:
@@ -2150,7 +2187,7 @@ class gjots_gui:
 			for name, file in self.icons.iteritems():
 				self.icons[name] = "./pixmaps/" + self.icons[name]
 
-		self.xml = gtk.glade.XML(self.gui_filename, "gjots")
+		self.xml = gtk.glade.XML(self.gui_filename, "gjots", domain="gjots2")
 		self.xml.signal_autoconnect(callbacks)
 		self.treestore = None
 		self.gjots = self.xml.get_widget("gjots")
@@ -2162,12 +2199,12 @@ class gjots_gui:
 		self.treeView = self.xml.get_widget("treeView")
 		self.appbar = self.xml.get_widget("appbar")
 		self.treeRightClickMenu = self.xml.get_widget("treeRightClickMenu")
-		#self.xmlMenu = gtk.glade.XML(self.gui_filename, "treeRightClickWindow")
+		#self.xmlMenu = gtk.glade.XML(self.gui_filename, "treeRightClickWindow", domain="gjots2")
 		self.last_message = ""
 		self.appbar.set_default(self.last_message)
 		self.dirtyflag = ""
 		self._create_empty_tree()
-		self.temp_text = "New...>>>" # must be odd enough to never be in the user's text - problem when documenting gjots itself??
+		self.temp_text = _("New...>>>") # must be odd enough to never be in the user's text - problem when documenting gjots itself??
 		self.tree_cutbuffer = None
 		self.current_item = None
 
@@ -2184,7 +2221,7 @@ class gjots_gui:
 		self.textView.set_buffer(self.textBuffer)
 		self.textBuffer.set_text("", 0)
 		self.textBuffer_changed_handler = self.textBuffer.connect("changed", self.on_textBuffer_changed)
-		self.treeView.get_selection().connect("changed", self.on_tree_selection_changed)
+		self.on_tree_selection_changed_handler = self.treeView.get_selection().connect("changed", self.on_tree_selection_changed)
 		self.readOnly_widget = self.xml.get_widget("readOnlyMenuItem")
 		self.readOnly_handler = self.readOnly_widget.connect("activate", self.on_readOnly_trigger)
 		self._setup_gconf()
@@ -2223,7 +2260,7 @@ class gjots_gui:
 		self._warp(self.root)
 		#self.treeView.get_selection().select_path(root_path)
 
-		self.msg(progName + ": version " + gjots_version)
+		self.msg(progName + _(": version ") + gjots_version)
 		self.set_readonly(readonly, quietly=1)
 
 		self.treeView.grab_focus()
